{\displaystyle \sigma ^{2}} {\displaystyle s^{2}} {\displaystyle \operatorname {Var} (X)} {\displaystyle V(X)} {\displaystyle \mathbb {V} (X)} {\displaystyle X} {\displaystyle X} {\displaystyle \mu =\operatorname {E} [X]} {\displaystyle \operatorname {Var} (X)=\operatorname {E} \left[(X-\mu )^{2}\right].} {\displaystyle \operatorname {Var} (X)=\operatorname {Cov} (X,X).} {\displaystyle X} {\displaystyle \operatorname {Var} (X)} {\displaystyle V(X)} {\displaystyle \mathbb {V} (X)} {\displaystyle \sigma _{X}^{2}} {\displaystyle \sigma ^{2}} {\displaystyle {\begin{aligned}\operatorname {Var} (X)&=\operatorname {E} \left[(X-\operatorname {E} [X])^{2}\right]\\[4pt]&=\operatorname {E} \left[X^{2}-2X\operatorname {E} [X]+\operatorname {E} [X]^{2}\right]\\[4pt]&=\operatorname {E} \left[X^{2}\right]-2\operatorname {E} [X]\operatorname {E} [X]+\operatorname {E} [X]^{2}\\[4pt]&=\operatorname {E} \left[X^{2}\right]-2\operatorname {E} [X]^{2}+\operatorname {E} [X]^{2}\\[4pt]&=\operatorname {E} \left[X^{2}\right]-\operatorname {E} [X]^{2}\end{aligned}}} {\displaystyle X} {\displaystyle x_{1}\mapsto p_{1},x_{2}\mapsto p_{2},\ldots ,x_{n}\mapsto p_{n}} {\displaystyle \operatorname {Var} (X)=\sum _{i=1}^{n}p_{i}\cdot (x_{i}-\mu )^{2},} {\displaystyle \mu } {\displaystyle \mu =\sum _{i=1}^{n}p_{i}x_{i}.} {\displaystyle n} {\displaystyle \operatorname {Var} (X)={\frac {1}{n}}\sum _{i=1}^{n}(x_{i}-\mu )^{2}} {\displaystyle \mu } {\displaystyle \mu ={\frac {1}{n}}\sum _{i=1}^{n}x_{i}.} {\displaystyle n} {\displaystyle \operatorname {Var} (X)={\frac {1}{n^{2}}}\sum _{i=1}^{n}\sum _{j=1}^{n}{\frac {1}{2}}(x_{i}-x_{j})^{2}={\frac {1}{n^{2}}}\sum _{i}\sum _{j>i}(x_{i}-x_{j})^{2}.} {\displaystyle X} {\displaystyle f(x)} {\displaystyle F(x)} {\displaystyle {\begin{aligned}\operatorname {Var} (X)=\sigma ^{2}&=\int _{\mathbb {R} }(x-\mu )^{2}f(x)\,dx\\[4pt]&=\int _{\mathbb {R} }x^{2}f(x)\,dx-2\mu \int _{\mathbb {R} }xf(x)\,dx+\mu ^{2}\int _{\mathbb {R} }f(x)\,dx\\[4pt]&=\int _{\mathbb {R} }x^{2}\,dF(x)-2\mu \int _{\mathbb {R} }x\,dF(x)+\mu ^{2}\int _{\mathbb {R} }\,dF(x)\\[4pt]&=\int _{\mathbb {R} }x^{2}\,dF(x)-2\mu \cdot \mu +\mu ^{2}\cdot 1\\[4pt]&=\int _{\mathbb {R} }x^{2}\,dF(x)-\mu ^{2},\end{aligned}}} {\displaystyle \operatorname {Var} (X)=\int _{\mathbb {R} }x^{2}f(x)\,dx-\mu ^{2},} {\displaystyle \mu } {\displaystyle X} {\displaystyle \mu =\int _{\mathbb {R} }xf(x)\,dx=\int _{\mathbb {R} }x\,dF(x).} {\displaystyle dx} {\displaystyle dF(x)} {\displaystyle x^{2}f(x)} {\displaystyle [a,b]\subset \mathbb {R} ,} {\displaystyle \operatorname {Var} (X)=\int _{-\infty }^{+\infty }x^{2}f(x)\,dx-\mu ^{2},} {\displaystyle f(x)=\lambda e^{-\lambda x}} {\displaystyle \operatorname {E} [X]=\int _{0}^{\infty }x\lambda e^{-\lambda x}\,dx={\frac {1}{\lambda }}.} {\displaystyle {\begin{aligned}\operatorname {E} \left[X^{2}\right]&=\int _{0}^{\infty }x^{2}\lambda e^{-\lambda x}\,dx\\&=\left[-x^{2}e^{-\lambda x}\right]_{0}^{\infty }+\int _{0}^{\infty }2xe^{-\lambda x}\,dx\\&=0+{\frac {2}{\lambda }}\operatorname {E} [X]\\&={\frac {2}{\lambda ^{2}}}.\end{aligned}}} {\displaystyle \operatorname {Var} (X)=\operatorname {E} \left[X^{2}\right]-\operatorname {E} [X]^{2}={\frac {2}{\lambda ^{2}}}-\left({\frac {1}{\lambda }}\right)^{2}={\frac {1}{\lambda ^{2}}}.} {\displaystyle (1+2+3+4+5+6)/6=7/2.} {\displaystyle {\begin{aligned}\operatorname {Var} (X)&=\sum _{i=1}^{6}{\frac {1}{6}}\left(i-{\frac {7}{2}}\right)^{2}\\[5pt]&={\frac {1}{6}}\left((-5/2)^{2}+(-3/2)^{2}+(-1/2)^{2}+(1/2)^{2}+(3/2)^{2}+(5/2)^{2}\right)\\[5pt]&={\frac {35}{12}}\approx 2.92.\end{aligned}}} {\displaystyle {\begin{aligned}\operatorname {Var} (X)&=\operatorname {E} \left(X^{2}\right)-(\operatorname {E} (X))^{2}\\[5pt]&={\frac {1}{n}}\sum _{i=1}^{n}i^{2}-\left({\frac {1}{n}}\sum _{i=1}^{n}i\right)^{2}\\[5pt]&={\frac {(n+1)(2n+1)}{6}}-\left({\frac {n+1}{2}}\right)^{2}\\[4pt]&={\frac {n^{2}-1}{12}}.\end{aligned}}} {\displaystyle \Pr \,(X=k)={\binom {n}{k}}p^{k}(1-p)^{n-k}} {\displaystyle np} {\displaystyle np(1-p)} {\displaystyle \Pr \,(X=k)=(1-p)^{k-1}p} {\displaystyle {\frac {1}{p}}} {\displaystyle {\frac {(1-p)}{p^{2}}}} {\displaystyle f\left(x\mid \mu ,\sigma ^{2}\right)={\frac {1}{\sqrt {2\pi \sigma ^{2}}}}e^{-{\frac {(x-\mu )^{2}}{2\sigma ^{2}}}}} {\displaystyle \mu } {\displaystyle \sigma ^{2}} {\displaystyle f(x\mid a,b)={\begin{cases}{\frac {1}{b-a}}&{\text{for }}a\leq x\leq b,\\[3pt]0&{\text{for }}xb\end{cases}}} {\displaystyle {\frac {a+b}{2}}} {\displaystyle {\frac {(b-a)^{2}}{12}}} {\displaystyle f(x\mid \lambda )=\lambda e^{-\lambda x}} {\displaystyle {\frac {1}{\lambda }}} {\displaystyle {\frac {1}{\lambda ^{2}}}} {\displaystyle f(k\mid \lambda )={\frac {e^{-\lambda }\lambda ^{k}}{k!}}} {\displaystyle \lambda } {\displaystyle \lambda } {\displaystyle \operatorname {Var} (X)\geq 0.} {\displaystyle \operatorname {Var} (a)=0.} {\displaystyle \operatorname {Var} (X)=0\iff \exists a:P(X=a)=1.} {\displaystyle k} {\displaystyle 1